@@ -141,6 +141,18 @@ class GeoArray(object):
             if self.filePath:
                 self.set_gdalDataset_meta()
 
+            if 'nodata' in self._initParams and self._initParams['nodata'] is not None:
+                self._validate_nodataVal()
+
+    def _validate_nodataVal(self):
+        """Check if a given nodata value is within the valid value range of the data type."""
+        if (np.issubdtype(self.dtype, np.integer) and
+           not np.can_cast(self._initParams['nodata'], self.dtype)) or \
+           (np.issubdtype(self.dtype, np.floating) and
+           not np.can_cast(float(self._initParams['nodata']), self.dtype)):
+            raise ValueError("The given no-data value (%s) is out range for data type %s."
+                             % (self._initParams['nodata'], self.dtype))
+
     @property
     def arr(self):
         return self._arr
@@ -182,7 +194,7 @@ class GeoArray(object):
             bN_dict = OrderedDict((band, i) for i, band in enumerate(list_bandnames))
 
             if len(bN_dict) != self.bands:
-                raise ValueError('Bands must different names. Received band list: %s' % list_bandnames)
+                raise ValueError('Bands must have unique names. Received band list: %s' % list_bandnames)
 
             self._bandnames = bN_dict
 
